graphium.nn
====================

Base structures for neural networks in the library (to be inherented by other modules)

=== "Contents"

    * [Base Graph Layer](#base-graph-layer)
    * [Base Layers](#base-layers)
    * [Residual Connection](#residual-connections)

## Base Graph Layer
------------
::: graphium.nn.base_graph_layer


## Base Layers
------------
::: graphium.nn.base_layers


## Residual Connections
------------
::: graphium.nn.residual_connections

